@@ -166,7 +166,7 @@ void SendExistingMedia(
 			), [=](const MTPUpdates &result, const MTP::Response &response) {
 		}, [=](const MTP::Error &error, const MTP::Response &response) {
 			if (error.code() == 400
-				&& error.type().startsWith(qstr("FILE_REFERENCE_"))) {
+				&& error.type().startsWith(u"FILE_REFERENCE_"_q)) {
 				api->refreshFileReference(origin, [=](const auto &result) {
 					if (media->fileReference() != usedFileReference) {
 						repeatRequest(repeatRequest);
