@@ -21,12 +21,15 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "chat_helpers/emoji_suggestions_widget.h"
 #include "countries/countries_instance.h" // Countries::ExtractPhoneCode.
 #include "window/window_session_controller.h"
+#include "menu/menu_ttl.h"
 #include "ui/widgets/checkbox.h"
 #include "ui/widgets/buttons.h"
 #include "ui/widgets/labels.h"
 #include "ui/toast/toast.h"
 #include "ui/special_buttons.h"
 #include "ui/widgets/fields/special_fields.h"
+#include "ui/widgets/popup_menu.h"
+#include "ui/text/format_values.h"
 #include "ui/text/text_options.h"
 #include "ui/text/text_utilities.h"
 #include "ui/unread_badge.h"
@@ -42,8 +45,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "api/api_invite_links.h"
 #include "api/api_peer_photo.h"
 #include "main/main_session.h"
-#include "facades.h"
+#include "styles/style_info.h"
 #include "styles/style_layers.h"
+#include "styles/style_menu_icons.h"
 #include "styles/style_boxes.h"
 #include "styles/style_dialogs.h"
 #include "styles/style_widgets.h"
@@ -54,19 +58,20 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 namespace {
 
 bool IsValidPhone(QString phone) {
-	phone = phone.replace(QRegularExpression(qsl("[^\\d]")), QString());
+	phone = phone.replace(QRegularExpression(u"[^\\d]"_q), QString());
 	return (phone.length() >= 8)
-		|| (phone == qsl("333"))
-		|| (phone.startsWith(qsl("42"))
+		|| (phone == u"333"_q)
+		|| (phone.startsWith(u"42"_q)
 			&& (phone.length() == 2
 				|| phone.length() == 5
 				|| phone.length() == 6
-				|| phone == qsl("4242")));
+				|| phone == u"4242"_q));
 }
 
 void ChatCreateDone(
 		not_null<Window::SessionNavigation*> navigation,
 		QImage image,
+		TimeId ttlPeriod,
 		const MTPUpdates &updates) {
 	navigation->session().api().applyUpdates(updates);
 
@@ -98,7 +103,10 @@ void ChatCreateDone(
 					chat,
 					std::move(image));
 			}
-			Ui::showPeerHistory(chat, ShowAtUnreadMsgId);
+			if (ttlPeriod) {
+				chat->setMessagesTTL(ttlPeriod);
+			}
+			navigation->showPeerHistory(chat);
 		};
 	if (!success) {
 		LOG(("API Error: chat not found in updates "
@@ -113,7 +121,7 @@ TextWithEntities PeerFloodErrorText(
 		PeerFloodType type) {
 	const auto link = Ui::Text::Link(
 		tr::lng_cant_more_info(tr::now),
-		session->createInternalLinkFull(qsl("spambot")));
+		session->createInternalLinkFull(u"spambot"_q));
 	return ((type == PeerFloodType::InviteGroup)
 		? tr::lng_cant_invite_not_contact
 		: tr::lng_cant_send_to_not_contact)(
@@ -398,7 +406,9 @@ void AddContactBox::save() {
 			: extractUser(list.front());
 		if (user) {
 			if (user->isContact() || user->session().supportMode()) {
-				Ui::showPeerHistory(user, ShowAtTheEndMsgId);
+				if (const auto window = user->session().tryResolveWindow()) {
+					window->showPeerHistory(user);
+				}
 			}
 			if (weak) { // showPeerHistory could close the box.
 				getDelegate()->hideLayer();
@@ -515,6 +525,39 @@ void GroupInfoBox::prepare() {
 		[=] { submit(); });
 	addButton(tr::lng_cancel(), [this] { closeBox(); });
 
+	if (_type == Type::Group) {
+		const auto top = addTopButton(st::infoTopBarMenu);
+		const auto menu =
+			top->lifetime().make_state<base::unique_qptr<Ui::PopupMenu>>();
+		top->setClickedCallback([=] {
+			*menu = base::make_unique_q<Ui::PopupMenu>(
+				top,
+				st::popupMenuWithIcons);
+
+			const auto text = tr::lng_manage_messages_ttl_menu(tr::now)
+				+ (_ttlPeriod
+					? ('\t' + Ui::FormatTTLTiny(_ttlPeriod))
+					: QString());
+			(*menu)->addAction(
+				text,
+				[=, show = std::make_shared<Ui::BoxShow>(this)] {
+					show->showBox(Box(TTLMenu::TTLBox, TTLMenu::Args{
+						.show = show,
+						.startTtl = _ttlPeriod,
+						.about = nullptr,
+						.callback = crl::guard(this, [=](
+								TimeId t,
+								Fn<void()> close) {
+							_ttlPeriod = t;
+							close();
+						}),
+					}));
+				}, &st::menuIconTTL);
+			(*menu)->popup(QCursor::pos());
+			return true;
+		});
+	}
+
 	updateMaxHeight();
 }
 
@@ -592,14 +635,18 @@ void GroupInfoBox::createGroup(
 		return;
 	}
 	_creationRequestId = _api.request(MTPmessages_CreateChat(
+		MTP_flags(_ttlPeriod
+			? MTPmessages_CreateChat::Flag::f_ttl_period
+			: MTPmessages_CreateChat::Flags(0)),
 		MTP_vector<TLUsers>(inputs),
-		MTP_string(title)
+		MTP_string(title),
+		MTP_int(_ttlPeriod)
 	)).done([=](const MTPUpdates &result) {
 		auto image = _photo->takeResultImage();
 		const auto navigation = _navigation;
 
 		getDelegate()->hideLayer(); // Destroys 'this'.
-		ChatCreateDone(navigation, std::move(image), result);
+		ChatCreateDone(navigation, std::move(image), _ttlPeriod, result);
 	}).fail([=](const MTP::Error &error) {
 		const auto &type = error.type();
 		_creationRequestId = 0;
@@ -675,15 +722,19 @@ void GroupInfoBox::createChannel(
 		const QString &description) {
 	Expects(!_creationRequestId);
 
-	const auto flags = (_type == Type::Megagroup)
-		? MTPchannels_CreateChannel::Flag::f_megagroup
-		: MTPchannels_CreateChannel::Flag::f_broadcast;
+	const auto flags = ((_type == Type::Megagroup)
+			? MTPchannels_CreateChannel::Flag::f_megagroup
+			: MTPchannels_CreateChannel::Flag::f_broadcast)
+		| (_ttlPeriod
+			? MTPchannels_CreateChannel::Flag::f_ttl_period
+			: MTPchannels_CreateChannel::Flags(0));
 	_creationRequestId = _api.request(MTPchannels_CreateChannel(
 		MTP_flags(flags),
 		MTP_string(title),
 		MTP_string(description),
 		MTPInputGeoPoint(), // geo_point
-		MTPstring() // address
+		MTPstring(), // address
+		MTP_int((_type == Type::Megagroup) ? _ttlPeriod : 0)
 	)).done([=](const MTPUpdates &result) {
 		_navigation->session().api().applyUpdates(result);
 
@@ -716,6 +767,9 @@ void GroupInfoBox::createChannel(
 						channel,
 						std::move(image));
 				}
+				if (_ttlPeriod && channel->isMegagroup()) {
+					channel->setMessagesTTL(_ttlPeriod);
+				}
 				channel->session().api().requestFullPeer(channel);
 				_createdChannel = channel;
 				checkInviteLink();
@@ -1225,6 +1279,8 @@ SetupChannelBox::UsernameResult SetupChannelBox::parseError(
 		return UsernameResult::Invalid;
 	} else if (error == u"USERNAME_OCCUPIED"_q) {
 		return UsernameResult::Occupied;
+	} else if (error == u"USERNAME_PURCHASE_AVAILABLE"_q) {
+		return UsernameResult::Occupied;
 	} else if (error == u"USERNAMES_UNAVAILABLE"_q) {
 		return UsernameResult::Occupied;
 	} else if (error == u"CHANNEL_PUBLIC_GROUP_NA"_q) {
