@@ -13,6 +13,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/widgets/labels.h"
 #include "ui/widgets/scroll_area.h"
 #include "ui/widgets/popup_menu.h"
+#include "ui/effects/loading_element.h"
 #include "ui/effects/round_checkbox.h"
 #include "ui/effects/ripple_animation.h"
 #include "ui/empty_userpic.h"
@@ -47,12 +48,31 @@ PaintRoundImageCallback PaintUserpicCallback(
 			};
 		}
 	}
-	auto userpic = std::shared_ptr<Data::CloudImageView>();
+	auto userpic = Ui::PeerUserpicView();
 	return [=](Painter &p, int x, int y, int outerWidth, int size) mutable {
 		peer->paintUserpicLeft(p, userpic, x, y, outerWidth, size);
 	};
 }
 
+PaintRoundImageCallback ForceRoundUserpicCallback(not_null<PeerData*> peer) {
+	auto userpic = Ui::PeerUserpicView();
+	auto cache = std::make_shared<QImage>();
+	return [=](Painter &p, int x, int y, int outerWidth, int size) mutable {
+		const auto ratio = style::DevicePixelRatio();
+		const auto cacheSize = QSize(size, size) * ratio;
+		if (cache->size() != cacheSize) {
+			*cache = QImage(cacheSize, QImage::Format_ARGB32_Premultiplied);
+			cache->setDevicePixelRatio(ratio);
+		}
+		auto q = Painter(cache.get());
+		peer->paintUserpicLeft(q, userpic, 0, 0, outerWidth, size);
+		q.end();
+
+		*cache = Images::Circle(std::move(*cache));
+		p.drawImage(x, y, *cache);
+	};
+}
+
 PeerListContentDelegateShow::PeerListContentDelegateShow(
 	std::shared_ptr<Ui::Show> show)
 : _show(show) {
@@ -355,14 +375,6 @@ void PeerListController::setDescriptionText(const QString &text) {
 	}
 }
 
-void PeerListController::setSearchLoadingText(const QString &text) {
-	if (text.isEmpty()) {
-		setSearchLoading(nullptr);
-	} else {
-		setSearchLoading(object_ptr<Ui::FlatLabel>(nullptr, text, st::membersAbout));
-	}
-}
-
 void PeerListController::setSearchNoResultsText(const QString &text) {
 	if (text.isEmpty()) {
 		setSearchNoResults(nullptr);
@@ -419,7 +431,9 @@ void PeerListBox::addSelectItem(
 	addSelectItem(
 		peer->id.value,
 		text,
-		PaintUserpicCallback(peer, respect),
+		(peer->isForum()
+			? ForceRoundUserpicCallback(peer)
+			: PaintUserpicCallback(peer, respect)),
 		animated);
 }
 
@@ -429,7 +443,7 @@ void PeerListBox::addSelectItem(
 	addSelectItem(
 		row->id(),
 		row->generateShortName(),
-		row->generatePaintUserpicCallback(),
+		row->generatePaintUserpicCallback(true),
 		animated);
 }
 
@@ -642,18 +656,22 @@ QString PeerListRow::generateShortName() {
 		: peer()->shortName();
 }
 
-std::shared_ptr<Data::CloudImageView> &PeerListRow::ensureUserpicView() {
-	if (!_userpic) {
+Ui::PeerUserpicView &PeerListRow::ensureUserpicView() {
+	if (!_userpic.cloud && peer()->hasUserpic()) {
 		_userpic = peer()->createUserpicView();
 	}
 	return _userpic;
 }
 
-PaintRoundImageCallback PeerListRow::generatePaintUserpicCallback() {
+PaintRoundImageCallback PeerListRow::generatePaintUserpicCallback(
+		bool forceRound) {
 	const auto saved = _isSavedMessagesChat;
 	const auto replies = _isRepliesMessagesChat;
 	const auto peer = this->peer();
-	auto userpic = saved ? nullptr : ensureUserpicView();
+	auto userpic = saved ? Ui::PeerUserpicView() : ensureUserpicView();
+	if (forceRound && peer->isForum()) {
+		return ForceRoundUserpicCallback(peer);
+	}
 	return [=](Painter &p, int x, int y, int outerWidth, int size) mutable {
 		if (saved) {
 			Ui::EmptyUserpic::PaintSavedMessages(p, x, y, outerWidth, size);
@@ -776,7 +794,7 @@ void PeerListRow::paintUserpic(
 		paintDisabledCheckUserpic(p, st, x, y, outerWidth);
 	} else if (_checkbox) {
 		_checkbox->paint(p, x, y, outerWidth);
-	} else if (const auto callback = generatePaintUserpicCallback()) {
+	} else if (const auto callback = generatePaintUserpicCallback(false)) {
 		callback(p, x, y, outerWidth, st.photoSize);
 	}
 }
@@ -847,15 +865,15 @@ void PeerListRow::lazyInitialize(const style::PeerListItem &st) {
 void PeerListRow::createCheckbox(
 		const style::RoundImageCheckbox &st,
 		Fn<void()> updateCallback) {
-	const auto generateRadius = [=] {
+	const auto generateRadius = [=](int size) {
 		return (!special() && peer()->isForum())
-			? ImageRoundRadius::Large
-			: ImageRoundRadius::Ellipse;
+			? int(size * Ui::ForumUserpicRadiusMultiplier())
+			: std::optional<int>();
 	};
 	_checkbox = std::make_unique<Ui::RoundImageCheckbox>(
 		st,
 		std::move(updateCallback),
-		generatePaintUserpicCallback(),
+		generatePaintUserpicCallback(false),
 		generateRadius);
 }
 
@@ -1243,7 +1261,7 @@ int PeerListContent::labelHeight() const {
 		if (!_filterResults.empty()) {
 			return 0;
 		}
-		if (_controller->isSearchLoading()) {
+		if (_controller->isSearchLoading() && _searchLoading) {
 			return computeLabelHeight(_searchLoading);
 		}
 		return computeLabelHeight(_searchNoResults);
@@ -1279,11 +1297,20 @@ void PeerListContent::setSearchMode(PeerListSearchMode mode) {
 		}
 		_searchMode = mode;
 		if (_controller->hasComplexSearch()) {
-			if (!_searchLoading) {
-				setSearchLoading(object_ptr<Ui::FlatLabel>(
-					this,
-					tr::lng_contacts_loading(tr::now),
-					st::membersAbout));
+			if (_mode == Mode::Custom) {
+				if (!_searchLoading) {
+					setSearchLoading(object_ptr<Ui::FlatLabel>(
+						this,
+						tr::lng_contacts_loading(tr::now),
+						st::membersAbout));
+				}
+			} else {
+				if (!_loadingAnimation) {
+					_loadingAnimation = Ui::CreateLoadingPeerListItemWidget(
+						this,
+						_st.item,
+						2);
+				}
 			}
 		} else {
 			clearSearchRows();
@@ -1378,6 +1405,14 @@ int PeerListContent::resizeGetHeight(int newWidth) {
 		_searchLoading->moveToLeft(st::contactsPadding.left(), labelTop + st::membersAboutLimitPadding.top(), newWidth);
 		_searchLoading->setVisible(!hideAll && showingSearch() && _filterResults.empty() && _controller->isSearchLoading());
 	}
+	if (_loadingAnimation) {
+		_loadingAnimation->resizeToWidth(newWidth);
+		_loadingAnimation->moveToLeft(0, rowsTop(), newWidth);
+		_loadingAnimation->setVisible(!hideAll
+			&& showingSearch()
+			&& _filterResults.empty()
+			&& _controller->isSearchLoading());
+	}
 	const auto label = labelHeight();
 	const auto belowTop = (label > 0 || rowsCount > 0)
 		? (labelTop + label + _st.padding.bottom())
