@@ -1258,9 +1258,7 @@ base::unique_qptr<Ui::PopupMenu> Members::Controller::createRowContextMenu(
 			result->menu(),
 			st::groupCallPopupCoverMenu,
 			st::groupCallMenuCover,
-			Info::Profile::NameValue(
-				participantPeer
-			) | rpl::map([](const auto &text) { return text.text; }),
+			Info::Profile::NameValue(participantPeer),
 			PrepareShortInfoStatus(participantPeer),
 			PrepareShortInfoUserpic(
 				participantPeer,
@@ -1644,7 +1642,7 @@ void Members::setupAddMember(not_null<GroupCall*> call) {
 			return rpl::single(false) | rpl::type_erased();
 		}
 		return rpl::combine(
-			Data::CanWriteValue(peer.get()),
+			Data::CanWriteValue(peer, false),
 			_call->joinAsValue()
 		) | rpl::map([=](bool can, not_null<PeerData*> joinAs) {
 			return can && joinAs->isSelf();
