@@ -225,7 +225,7 @@ void EditLinkBox(
 
 TextWithEntities StripSupportHashtag(TextWithEntities &&text) {
 	static const auto expression = QRegularExpression(
-		qsl("\\n?#tsf[a-z0-9_-]*[\\s#a-z0-9_-]*$"),
+		u"\\n?#tsf[a-z0-9_-]*[\\s#a-z0-9_-]*$"_q,
 		QRegularExpression::CaseInsensitiveOption);
 	const auto match = expression.match(text.text);
 	if (!match.hasMatch()) {
@@ -435,7 +435,7 @@ InlineBotQuery ParseInlineBotQuery(
 		auto inlineUsernameEqualsText = (inlineUsernameEnd == textLength);
 		auto validInlineUsername = false;
 		if (inlineUsernameEqualsText) {
-			validInlineUsername = text.endsWith(qstr("bot"));
+			validInlineUsername = text.endsWith(u"bot"_q);
 		} else if (inlineUsernameEnd < textLength && inlineUsernameLength) {
 			validInlineUsername = text[inlineUsernameEnd].isSpace();
 		}
