@@ -91,6 +91,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "boxes/premium_limits_box.h"
 #include "ui/boxes/confirm_box.h"
 
+#include <QtCore/QStandardPaths>
 #include <QtCore/QMimeDatabase>
 #include <QtGui/QGuiApplication>
 #include <QtGui/QScreen>
@@ -236,6 +237,7 @@ void Application::run() {
 	refreshGlobalProxy(); // Depends on app settings being read.
 
 	if (const auto old = Local::oldSettingsVersion(); old < AppVersion) {
+		Platform::InstallLauncher();
 		RegisterUrlScheme();
 		Platform::NewVersionLaunched(old);
 	}
@@ -250,6 +252,15 @@ void Application::run() {
 		return;
 	}
 
+	if (KSandbox::isInside()) {
+		const auto path = settings().downloadPath();
+		if (!path.isEmpty()
+			&& path != FileDialog::Tmp()
+			&& !base::CanReadDirectory(path)) {
+			settings().setDownloadPath(QString());
+		}
+	}
+
 	_translator = std::make_unique<Lang::Translator>();
 	QCoreApplication::instance()->installTranslator(_translator.get());
 
@@ -279,7 +290,7 @@ void Application::run() {
 	DEBUG_LOG(("Application Info: starting app..."));
 
 	// Create mime database, so it won't be slow later.
-	QMimeDatabase().mimeTypeForName(qsl("text/plain"));
+	QMimeDatabase().mimeTypeForName(u"text/plain"_q);
 
 	_primaryWindow = std::make_unique<Window::Controller>();
 	_lastActiveWindow = _primaryWindow.get();
@@ -559,7 +570,7 @@ bool Application::eventFilter(QObject *object, QEvent *e) {
 			const auto event = static_cast<QFileOpenEvent*>(e);
 			const auto url = QString::fromUtf8(
 				event->url().toEncoded().trimmed());
-			if (url.startsWith(qstr("tg://"), Qt::CaseInsensitive)) {
+			if (url.startsWith(u"tg://"_q, Qt::CaseInsensitive)) {
 				cSetStartUrl(url.mid(0, 8192));
 				checkStartUrl();
 			}
@@ -588,9 +599,15 @@ void Application::saveSettings() {
 }
 
 bool Application::canSaveFileWithoutAskingForPath() const {
-	return !Core::App().settings().askDownloadPath()
-		&& (!KSandbox::isInside()
-			|| !Core::App().settings().downloadPath().isEmpty());
+	if (Core::App().settings().askDownloadPath()) {
+		return false;
+	} else if (KSandbox::isInside()
+		&& Core::App().settings().downloadPath().isEmpty()) {
+		const auto path = QStandardPaths::writableLocation(
+			QStandardPaths::DownloadLocation);
+		return base::CanReadDirectory(path);
+	}
+	return true;
 }
 
 MTP::Config &Application::fallbackProductionConfig() const {
@@ -838,16 +855,18 @@ void Application::switchDebugMode() {
 		Logs::SetDebugEnabled(true);
 		_launcher->writeDebugModeSetting();
 		DEBUG_LOG(("Debug logs started."));
-		Ui::hideLayer();
+		if (_primaryWindow) {
+			_primaryWindow->hideLayer();
+		}
 	}
 }
 
 void Application::switchFreeType() {
 	if (cUseFreeType()) {
-		QFile(cWorkingDir() + qsl("tdata/withfreetype")).remove();
+		QFile(cWorkingDir() + u"tdata/withfreetype"_q).remove();
 		cSetUseFreeType(false);
 	} else {
-		QFile f(cWorkingDir() + qsl("tdata/withfreetype"));
+		QFile f(cWorkingDir() + u"tdata/withfreetype"_q);
 		if (f.open(QIODevice::WriteOnly)) {
 			f.write("1");
 			f.close();
@@ -949,6 +968,12 @@ bool Application::canApplyLangPackWithoutRestart() const {
 	return true;
 }
 
+void Application::checkSendPaths() {
+	if (!cSendPaths().isEmpty() && _primaryWindow && !_primaryWindow->locked()) {
+		_primaryWindow->widget()->sendPaths();
+	}
+}
+
 void Application::checkStartUrl() {
 	if (!cStartUrl().isEmpty() && _primaryWindow && !_primaryWindow->locked()) {
 		const auto url = cStartUrl();
@@ -1219,13 +1244,12 @@ void Application::closeChatFromWindows(not_null<PeerData*> peer) {
 		const auto primary = _primaryWindow->sessionController();
 		if ((primary->activeChatCurrent().peer() == peer)
 			&& (&primary->session() == &peer->session())) {
-			// showChatsList
-			primary->showPeerHistory(
-				PeerId(0),
-				Window::SectionShow::Way::ClearStack);
+			primary->clearSectionStack();
 		}
-		if (primary->openedForum().current() == peer) {
-			primary->closeForum();
+		if (const auto forum = primary->shownForum().current()) {
+			if (peer->forum() == forum) {
+				primary->closeForum();
+			}
 		}
 	}
 }
@@ -1447,11 +1471,11 @@ void Application::RegisterUrlScheme() {
 	base::Platform::RegisterUrlScheme(base::Platform::UrlSchemeDescriptor{
 		.executable = cExeDir() + cExeName(),
 		.arguments = Sandbox::Instance().customWorkingDir()
-			? qsl("-workdir \"%1\"").arg(cWorkingDir())
+			? u"-workdir \"%1\""_q.arg(cWorkingDir())
 			: QString(),
-		.protocol = qsl("tg"),
-		.protocolName = qsl("Telegram Link"),
-		.shortAppName = qsl("tdesktop"),
+		.protocol = u"tg"_q,
+		.protocolName = u"Telegram Link"_q,
+		.shortAppName = u"tdesktop"_q,
 		.longAppName = QCoreApplication::applicationName(),
 		.displayAppName = AppName.utf16(),
 		.displayAppDescription = AppName.utf16(),
