@@ -17,7 +17,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "media/player/media_player_instance.h"
 #include "ui/gl/gl_detection.h"
 #include "calls/group/calls_group_common.h"
-#include "facades.h"
 
 namespace Core {
 namespace {
@@ -740,7 +739,7 @@ QString Settings::getSoundPath(const QString &key) const {
 	if (it != _soundOverrides.end()) {
 		return it->second;
 	}
-	return qsl(":/sounds/") + key + qsl(".mp3");
+	return u":/sounds/"_q + key + u".mp3"_q;
 }
 
 void Settings::setTabbedSelectorSectionEnabled(bool enabled) {
