@@ -12,6 +12,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include <QtCore/QStringList>
 #include <QtCore/QMimeType>
 
+class QMimeData;
+
 namespace Core {
 
 class MimeType {
@@ -47,4 +49,7 @@ private:
 
 [[nodiscard]] bool FileIsImage(const QString &name, const QString &mime);
 
+[[nodiscard]] std::shared_ptr<QMimeData> ShareMimeMediaData(
+	not_null<const QMimeData*> original);
+
 } // namespace Core
