@@ -164,9 +164,7 @@ void ChannelData::setFlags(ChannelDataFlags which) {
 	const auto taken = ((diff & Flag::Forum) && !(which & Flag::Forum))
 		? mgInfo->takeForumData()
 		: nullptr;
-	if (const auto raw = taken.get()) {
-		owner().forumIcons().clearUserpicsReset(taken.get());
-	} else if ((diff & Flag::Forum) && (which & Flag::Forum)) {
+	if ((diff & Flag::Forum) && (which & Flag::Forum)) {
 		mgInfo->ensureForum(this);
 	}
 	_flags.set(which);
@@ -183,9 +181,18 @@ void ChannelData::setFlags(ChannelDataFlags which) {
 			}
 			if (diff & Flag::Forum) {
 				Core::App().notifications().clearFromHistory(history);
+				history->updateChatListEntryHeight();
+				if (history->inChatList()) {
+					if (const auto forum = this->forum()) {
+						forum->preloadTopics();
+					}
+				}
 			}
 		}
 	}
+	if (const auto raw = taken.get()) {
+		owner().forumIcons().clearUserpicsReset(raw);
+	}
 }
 
 void ChannelData::addFlags(ChannelDataFlags which) {
@@ -936,12 +943,14 @@ void ApplyChannelUpdate(
 		| Flag::CanViewParticipants
 		| Flag::CanSetStickers
 		| Flag::PreHistoryHidden
+		| Flag::AntiSpam
 		| Flag::Location;
 	channel->setFlags((channel->flags() & ~mask)
 		| (update.is_can_set_username() ? Flag::CanSetUsername : Flag())
 		| (update.is_can_view_participants() ? Flag::CanViewParticipants : Flag())
 		| (update.is_can_set_stickers() ? Flag::CanSetStickers : Flag())
 		| (update.is_hidden_prehistory() ? Flag::PreHistoryHidden : Flag())
+		| (update.is_antispam() ? Flag::AntiSpam : Flag())
 		| (update.vlocation() ? Flag::Location : Flag()));
 	channel->setUserpicPhoto(update.vchat_photo());
 	if (const auto migratedFrom = update.vmigrated_from_chat_id()) {
