@@ -57,7 +57,7 @@ public:
 	void loadUserpic() override;
 	void paintUserpic(
 		Painter &p,
-		std::shared_ptr<Data::CloudImageView> &view,
+		Ui::PeerUserpicView &view,
 		const Dialogs::Ui::PaintContext &context) const override;
 	void paintUserpic(Painter &p, int x, int y, int size) const;
 	void paintUserpic(
