@@ -7,7 +7,11 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "dialogs/dialogs_row.h"
 
+#include "ui/chat/chat_theme.h" // CountAverageColor.
+#include "ui/color_contrast.h"
 #include "ui/effects/ripple_animation.h"
+#include "ui/image/image_prepare.h"
+#include "ui/text/format_values.h"
 #include "ui/text/text_options.h"
 #include "ui/text/text_utilities.h"
 #include "ui/painter.h"
@@ -22,10 +26,155 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/history_item.h"
 #include "lang/lang_keys.h"
 #include "base/unixtime.h"
-#include "mainwidget.h"
 #include "styles/style_dialogs.h"
 
 namespace Dialogs {
+namespace {
+
+constexpr auto kTopLayer = 2;
+constexpr auto kBottomLayer = 1;
+constexpr auto kNoneLayer = 0;
+
+[[nodiscard]] QImage CornerBadgeTTL(
+		not_null<PeerData*> peer,
+		Ui::PeerUserpicView &view,
+		int photoSize) {
+	const auto ttl = peer->messagesTTL();
+	if (!ttl) {
+		return QImage();
+	}
+	constexpr auto kBlurRadius = 24;
+
+	const auto ratio = style::DevicePixelRatio();
+	const auto fullSize = photoSize;
+	const auto blurredFull = Images::BlurLargeImage(
+		peer->generateUserpicImage(view, fullSize * ratio, 0),
+		kBlurRadius);
+	const auto partRect = CornerBadgeTTLRect(fullSize);
+	const auto &partSize = partRect.width();
+	auto result = [&] {
+		auto blurredPart = blurredFull.copy(
+			blurredFull.width() - partSize * ratio,
+			blurredFull.height() - partSize * ratio,
+			partSize * ratio,
+			partSize * ratio);
+		blurredPart.setDevicePixelRatio(ratio);
+
+		constexpr auto kMinAcceptableContrast = 4.5;
+		const auto averageColor = Ui::CountAverageColor(blurredPart);
+		const auto contrast = Ui::CountContrast(
+			averageColor,
+			st::premiumButtonFg->c);
+		if (contrast < kMinAcceptableContrast) {
+			constexpr auto kDarkerBy = 0.2;
+			auto painterPart = QPainter(&blurredPart);
+			painterPart.setOpacity(kDarkerBy);
+			painterPart.fillRect(
+				QRect(QPoint(), partRect.size()),
+				Qt::black);
+		}
+		return Images::Circle(std::move(blurredPart));
+	}();
+
+	auto q = QPainter(&result);
+	PainterHighQualityEnabler hq(q);
+
+	const auto innerRect = QRect(QPoint(), partRect.size())
+		- st::dialogsTTLBadgeInnerMargins;
+	const auto ttlText = Ui::FormatTTLTiny(ttl);
+
+	q.setFont(st::dialogsScamFont);
+	q.setPen(st::premiumButtonFg);
+	q.drawText(
+		innerRect,
+		(ttlText.size() > 2) ? ttlText.mid(0, 2) : ttlText,
+		style::al_center);
+
+	constexpr auto kPenWidth = 1.5;
+	constexpr auto kAngleStart = 90 * 16;
+	constexpr auto kAngleSpan = 180 * 16;
+
+	auto pen = QPen(st::premiumButtonFg);
+	pen.setJoinStyle(Qt::RoundJoin);
+	pen.setCapStyle(Qt::RoundCap);
+	pen.setWidthF(style::ConvertScaleExact(kPenWidth));
+
+	q.setPen(pen);
+	q.setBrush(Qt::NoBrush);
+	q.drawArc(innerRect, kAngleStart, kAngleSpan);
+
+	q.setClipRect(innerRect - QMargins(innerRect.width() / 2, 0, 0, 0));
+	pen.setStyle(Qt::DotLine);
+	q.setPen(pen);
+	q.drawEllipse(innerRect);
+
+	return result;
+}
+
+} // namespace
+
+QRect CornerBadgeTTLRect(int photoSize) {
+	const auto &partSize = st::dialogsTTLBadgeSize;
+	return QRect(
+		photoSize - partSize + st::dialogsTTLBadgeSkip.x(),
+		photoSize - partSize + st::dialogsTTLBadgeSkip.y(),
+		partSize,
+		partSize);
+}
+
+Row::CornerLayersManager::CornerLayersManager() = default;
+
+bool Row::CornerLayersManager::isSameLayer(Layer layer) const {
+	return isFinished() && (_nextLayer == layer);
+}
+
+void Row::CornerLayersManager::setLayer(
+		Layer layer,
+		Fn<void()> updateCallback) {
+	if (_nextLayer == layer) {
+		return;
+	}
+	_lastFrameShown = false;
+	_prevLayer = _nextLayer;
+	_nextLayer = layer;
+	if (_animation.animating()) {
+		_animation.change(
+			1.,
+			st::dialogsOnlineBadgeDuration * (1. - _animation.value(1.)));
+	} else if (updateCallback) {
+		_animation.start(
+			std::move(updateCallback),
+			0.,
+			1.,
+			st::dialogsOnlineBadgeDuration);
+	}
+}
+
+float64 Row::CornerLayersManager::progressForLayer(Layer layer) const {
+	return (_nextLayer == layer)
+		? progress()
+		: (_prevLayer == layer)
+		? (1. - progress())
+		: 0.;
+}
+
+float64 Row::CornerLayersManager::progress() const {
+	return _animation.value(1.);
+}
+
+bool Row::CornerLayersManager::isFinished() const {
+	return (progress() == 1.) && _lastFrameShown;
+}
+
+void Row::CornerLayersManager::markFrameShown() {
+	if (progress() == 1.) {
+		_lastFrameShown = true;
+	}
+}
+
+bool Row::CornerLayersManager::isDisplayedNone() const {
+	return (progress() == 1.) && (_nextLayer == 0);
+}
 
 BasicRow::BasicRow() = default;
 BasicRow::~BasicRow() = default;
@@ -100,10 +249,18 @@ void BasicRow::paintUserpic(
 Row::Row(Key key, int index, int top) : _id(key), _top(top), _index(index) {
 	if (const auto history = key.history()) {
 		updateCornerBadgeShown(history->peer);
-		_height = history->peer->isForum()
-			? st::forumDialogRow.height
+	}
+}
+
+void Row::recountHeight(float64 narrowRatio) {
+	if (const auto history = _id.history()) {
+		_height = history->isForum()
+			? anim::interpolate(
+				st::forumDialogRow.height,
+				st::defaultDialogRow.height,
+				narrowRatio)
 			: st::defaultDialogRow.height;
-	} else if (key.folder()) {
+	} else if (_id.folder()) {
 		_height = st::defaultDialogRow.height;
 	} else {
 		_height = st::forumTopicRow.height;
@@ -115,28 +272,25 @@ uint64 Row::sortKey(FilterId filterId) const {
 }
 
 void Row::setCornerBadgeShown(
-		bool shown,
+		CornerLayersManager::Layer nextLayer,
 		Fn<void()> updateCallback) const {
-	const auto value = (shown ? 1 : 0);
-	if (_cornerBadgeShown == value) {
-		return;
-	}
-	const_cast<Row*>(this)->_cornerBadgeShown = value;
-	if (_cornerBadgeUserpic && _cornerBadgeUserpic->animation.animating()) {
-		_cornerBadgeUserpic->animation.change(
-			_cornerBadgeShown ? 1. : 0.,
-			st::dialogsOnlineBadgeDuration);
-	} else if (updateCallback) {
-		ensureCornerBadgeUserpic();
-		_cornerBadgeUserpic->animation.start(
-			std::move(updateCallback),
-			_cornerBadgeShown ? 0. : 1.,
-			_cornerBadgeShown ? 1. : 0.,
-			st::dialogsOnlineBadgeDuration);
+	const auto cornerBadgeShown = (nextLayer ? 1 : 0);
+	if (_cornerBadgeShown == cornerBadgeShown) {
+		if (!cornerBadgeShown) {
+			return;
+		} else if (_cornerBadgeUserpic
+			&& _cornerBadgeUserpic->layersManager.isSameLayer(nextLayer)) {
+			return;
+		}
 	}
+	const_cast<Row*>(this)->_cornerBadgeShown = cornerBadgeShown;
+	ensureCornerBadgeUserpic();
+	_cornerBadgeUserpic->layersManager.setLayer(
+		nextLayer,
+		std::move(updateCallback));
 	if (!_cornerBadgeShown
 		&& _cornerBadgeUserpic
-		&& !_cornerBadgeUserpic->animation.animating()) {
+		&& _cornerBadgeUserpic->layersManager.isDisplayedNone()) {
 		_cornerBadgeUserpic = nullptr;
 	}
 }
@@ -146,16 +300,19 @@ void Row::updateCornerBadgeShown(
 		Fn<void()> updateCallback) const {
 	const auto user = peer->asUser();
 	const auto now = user ? base::unixtime::now() : TimeId();
-	const auto shown = [&] {
-		if (user) {
-			return Data::IsUserOnline(user, now);
-		} else if (const auto channel = peer->asChannel()) {
-			return Data::ChannelHasActiveCall(channel);
+	const auto nextLayer = [&] {
+		if (user && Data::IsUserOnline(user, now)) {
+			return kTopLayer;
+		} else if (peer->isChannel()
+			&& Data::ChannelHasActiveCall(peer->asChannel())) {
+			return kTopLayer;
+		} else if (peer->messagesTTL()) {
+			return kBottomLayer;
 		}
-		return false;
+		return kNoneLayer;
 	}();
-	setCornerBadgeShown(shown, std::move(updateCallback));
-	if (shown && user) {
+	setCornerBadgeShown(nextLayer, std::move(updateCallback));
+	if ((nextLayer == kTopLayer) && user) {
 		peer->owner().watchForOffline(user, now);
 	}
 }
@@ -171,7 +328,7 @@ void Row::PaintCornerBadgeFrame(
 		not_null<CornerBadgeUserpic*> data,
 		not_null<PeerData*> peer,
 		Ui::VideoUserpic *videoUserpic,
-		std::shared_ptr<Data::CloudImageView> &view,
+		Ui::PeerUserpicView &view,
 		const Ui::PaintContext &context) {
 	data->frame.fill(Qt::transparent);
 
@@ -187,6 +344,22 @@ void Row::PaintCornerBadgeFrame(
 		context.st->photoSize,
 		context.paused);
 
+	const auto &manager = data->layersManager;
+	if (const auto p = manager.progressForLayer(kBottomLayer); p) {
+		const auto size = context.st->photoSize;
+		if (data->cacheTTL.isNull() && peer->messagesTTL()) {
+			data->cacheTTL = CornerBadgeTTL(peer, view, size);
+		}
+		q.setOpacity(p);
+		const auto point = CornerBadgeTTLRect(size).topLeft();
+		q.drawImage(point, data->cacheTTL);
+		q.setOpacity(1.);
+	}
+	const auto topLayerProgress = manager.progressForLayer(kTopLayer);
+	if (!topLayerProgress) {
+		return;
+	}
+
 	PainterHighQualityEnabler hq(q);
 	q.setCompositionMode(QPainter::CompositionMode_Source);
 
@@ -197,10 +370,10 @@ void Row::PaintCornerBadgeFrame(
 	const auto skip = peer->isUser()
 		? st::dialogsOnlineBadgeSkip
 		: st::dialogsCallBadgeSkip;
-	const auto shrink = (size / 2) * (1. - data->shown);
+	const auto shrink = (size / 2) * (1. - topLayerProgress);
 
 	auto pen = QPen(Qt::transparent);
-	pen.setWidthF(stroke * data->shown);
+	pen.setWidthF(stroke * topLayerProgress);
 	q.setPen(pen);
 	q.setBrush(data->active
 		? st::dialogsOnlineBadgeFgActive
@@ -221,10 +394,10 @@ void Row::paintUserpic(
 		const Ui::PaintContext &context) const {
 	updateCornerBadgeShown(peer);
 
-	const auto shown = _cornerBadgeUserpic
-		? _cornerBadgeUserpic->animation.value(_cornerBadgeShown ? 1. : 0.)
-		: (_cornerBadgeShown ? 1. : 0.);
-	if (!historyForCornerBadge || shown == 0.) {
+	const auto cornerBadgeShown = !_cornerBadgeUserpic
+		? _cornerBadgeShown
+		: !_cornerBadgeUserpic->layersManager.isDisplayedNone();
+	if (!historyForCornerBadge || !cornerBadgeShown) {
 		BasicRow::paintUserpic(
 			p,
 			peer,
@@ -251,17 +424,21 @@ void Row::paintUserpic(
 			QImage::Format_ARGB32_Premultiplied);
 		_cornerBadgeUserpic->frame.setDevicePixelRatio(ratio);
 	}
-	const auto key = peer->userpicUniqueKey(userpicView());
+	auto key = peer->userpicUniqueKey(userpicView());
+	key.first += peer->messagesTTL();
 	const auto frameIndex = videoUserpic ? videoUserpic->frameIndex() : -1;
-	if (_cornerBadgeUserpic->shown != shown
+	if (_cornerBadgeUserpic->key != key) {
+		_cornerBadgeUserpic->cacheTTL = QImage();
+	}
+	if (!_cornerBadgeUserpic->layersManager.isFinished()
 		|| _cornerBadgeUserpic->key != key
 		|| _cornerBadgeUserpic->active != context.active
 		|| _cornerBadgeUserpic->frameIndex != frameIndex
 		|| videoUserpic) {
-		_cornerBadgeUserpic->shown = shown;
 		_cornerBadgeUserpic->key = key;
 		_cornerBadgeUserpic->active = context.active;
 		_cornerBadgeUserpic->frameIndex = frameIndex;
+		_cornerBadgeUserpic->layersManager.markFrameShown();
 		PaintCornerBadgeFrame(
 			_cornerBadgeUserpic.get(),
 			peer,
@@ -282,7 +459,8 @@ void Row::paintUserpic(
 		: st::dialogsBg;
 	const auto size = st::dialogsCallBadgeSize;
 	const auto skip = st::dialogsCallBadgeSkip;
-	p.setOpacity(shown);
+	p.setOpacity(
+		_cornerBadgeUserpic->layersManager.progressForLayer(kTopLayer));
 	p.translate(context.st->padding.left(), context.st->padding.top());
 	actionPainter->paintSpeaking(
 		p,
