@@ -13,9 +13,17 @@ class Image;
 class HistoryItem;
 enum class ImageRoundRadius;
 
+namespace style {
+struct DialogRow;
+} // namespace style
+
 namespace Ui {
 } // namespace Ui
 
+namespace Data {
+class Forum;
+} // namespace Data
+
 namespace HistoryView {
 struct ToPreviewOptions;
 struct ItemPreviewImage;
@@ -27,6 +35,8 @@ namespace Dialogs::Ui {
 using namespace ::Ui;
 
 struct PaintContext;
+struct TopicJumpCache;
+class TopicsView;
 
 [[nodiscard]] TextWithEntities DialogsPreviewText(TextWithEntities text);
 
@@ -42,22 +52,40 @@ public:
 	void itemInvalidated(not_null<const HistoryItem*> item);
 	[[nodiscard]] bool dependsOn(not_null<const HistoryItem*> item) const;
 
-	[[nodiscard]] bool prepared(not_null<const HistoryItem*> item) const;
+	[[nodiscard]] bool prepared(
+		not_null<const HistoryItem*> item,
+		Data::Forum *forum) const;
 	void prepare(
 		not_null<const HistoryItem*> item,
+		Data::Forum *forum,
 		Fn<void()> customEmojiRepaint,
 		ToPreviewOptions options);
+
 	void paint(
 		Painter &p,
 		const QRect &geometry,
 		const PaintContext &context) const;
 
+	[[nodiscard]] bool isInTopicJump(int x, int y) const;
+	void addTopicJumpRipple(
+		QPoint origin,
+		not_null<TopicJumpCache*> topicJumpCache,
+		Fn<void()> updateCallback);
+	void stopLastRipple();
+
 private:
 	struct LoadingContext;
 
+	[[nodiscard]] int countWidth() const;
+	void paintJumpToLast(
+		Painter &p,
+		const QRect &rect,
+		const PaintContext &context,
+		int width1) const;
+
 	mutable const HistoryItem *_textCachedFor = nullptr;
 	mutable Text::String _senderCache;
-	mutable Text::String _topicCache;
+	mutable std::unique_ptr<TopicsView> _topics;
 	mutable Text::String _textCache;
 	mutable std::vector<ItemPreviewImage> _imagesCache;
 	mutable std::unique_ptr<LoadingContext> _loadingContext;
