@@ -566,6 +566,10 @@ bool Element::isBubbleAttachedToNext() const {
 	return _flags & Flag::BubbleAttachedToNext;
 }
 
+bool Element::isTopicRootReply() const {
+	return _flags & Flag::TopicRootReply;
+}
+
 int Element::skipBlockWidth() const {
 	return st::msgDateSpace + infoWidth() - st::msgDateDelta.x();
 }
@@ -672,21 +676,17 @@ auto Element::contextDependentServiceText() -> TextWithLinks {
 	if (!info) {
 		return {};
 	}
-	const auto created = !info->closed
-		&& !info->reopened
-		&& !info->renamed
-		&& !info->reiconed;
 	if (_delegate->elementContext() == Context::Replies) {
-		if (created) {
+		if (info->created()) {
 			return { { tr::lng_action_topic_created_inside(tr::now) } };
 		}
 		return {};
-	} else if (created) {
+	} else if (info->created()) {
 		return{};
 	}
 	const auto peerId = item->history()->peer->id;
 	const auto topicRootId = item->topicRootId();
-	if (!topicRootId || !peerIsChannel(peerId)) {
+	if (!peerIsChannel(peerId)) {
 		return {};
 	}
 	const auto from = item->from();
@@ -705,7 +705,10 @@ auto Element::contextDependentServiceText() -> TextWithLinks {
 			const QString &title,
 			std::optional<DocumentId> iconId) {
 		return Ui::Text::Link(
-			Data::ForumTopicIconWithTitle(iconId.value_or(0), title),
+			Data::ForumTopicIconWithTitle(
+				topicRootId,
+				iconId.value_or(0),
+				title),
 			topicUrl);
 	};
 	const auto wrapParentTopic = [&] {
@@ -743,6 +746,22 @@ auto Element::contextDependentServiceText() -> TextWithLinks {
 				wrapParentTopic(),
 				Ui::Text::WithEntities),
 		};
+	} else if (info->hidden) {
+		return {
+			tr::lng_action_topic_hidden(
+				tr::now,
+				lt_topic,
+				wrapParentTopic(),
+				Ui::Text::WithEntities),
+		};
+	} else if (info->unhidden) {
+		return {
+			tr::lng_action_topic_unhidden(
+				tr::now,
+				lt_topic,
+				wrapParentTopic(),
+				Ui::Text::WithEntities),
+		};
 	} else if (info->renamed) {
 		return {
 			tr::lng_action_topic_renamed(
@@ -902,7 +921,8 @@ bool Element::computeIsAttachToPrevious(not_null<Element*> previous) {
 				< kAttachMessageToPreviousSecondsDelta)
 			&& mayBeAttached(this)
 			&& mayBeAttached(previous)
-			&& (!previousMarkup || previousMarkup->hiddenBy(prev->media()));
+			&& (!previousMarkup || previousMarkup->hiddenBy(prev->media()))
+			&& (item->topicRootId() == prev->topicRootId());
 		if (possible) {
 			const auto forwarded = item->Get<HistoryMessageForwarded>();
 			const auto prevForwarded = prev->Get<HistoryMessageForwarded>();
@@ -1006,10 +1026,10 @@ void Element::destroyUnreadBar() {
 		return;
 	}
 	RemoveComponents(UnreadBar::Bit());
-	history()->owner().requestViewResize(this);
 	if (data()->mainView() == this) {
 		recountAttachToPreviousInBlocks();
 	}
+	history()->owner().requestViewResize(this);
 }
 
 int Element::displayedDateHeight() const {
@@ -1065,17 +1085,35 @@ void Element::recountDisplayDateInBlocks() {
 }
 
 QSize Element::countOptimalSize() {
+	_flags &= ~Flag::NeedsResize;
 	return performCountOptimalSize();
 }
 
 QSize Element::countCurrentSize(int newWidth) {
 	if (_flags & Flag::NeedsResize) {
-		_flags &= ~Flag::NeedsResize;
 		initDimensions();
 	}
 	return performCountCurrentSize(newWidth);
 }
 
+void Element::refreshIsTopicRootReply() {
+	const auto topicRootReply = countIsTopicRootReply();
+	if (topicRootReply) {
+		_flags |= Flag::TopicRootReply;
+	} else {
+		_flags &= ~Flag::TopicRootReply;
+	}
+}
+
+bool Element::countIsTopicRootReply() const {
+	const auto item = data();
+	if (!item->history()->isForum()) {
+		return false;
+	}
+	const auto replyTo = item->replyToId();
+	return !replyTo || (item->topicRootId() == replyTo);
+}
+
 void Element::setDisplayDate(bool displayDate) {
 	const auto item = data();
 	if (displayDate && !Has<DateBadge>()) {
@@ -1153,6 +1191,10 @@ bool Element::displayFromName() const {
 	return false;
 }
 
+TopicButton *Element::displayedTopicButton() const {
+	return nullptr;
+}
+
 bool Element::displayForwardedFrom() const {
 	return false;
 }
@@ -1193,7 +1235,8 @@ void Element::drawRightAction(
 	int outerWidth) const {
 }
 
-ClickHandlerPtr Element::rightActionLink() const {
+ClickHandlerPtr Element::rightActionLink(
+		std::optional<QPoint> pressPoint) const {
 	return ClickHandlerPtr();
 }
 
