@@ -35,6 +35,7 @@ struct ChatPaintContext;
 class ChatStyle;
 struct ReactionFlyAnimationArgs;
 class ReactionFlyAnimation;
+class RippleAnimation;
 } // namespace Ui
 
 namespace HistoryView::Reactions {
@@ -237,6 +238,14 @@ struct DateBadge : public RuntimeComponent<DateBadge, Element> {
 
 };
 
+struct TopicButton {
+	std::unique_ptr<Ui::RippleAnimation> ripple;
+	ClickHandlerPtr link;
+	Ui::Text::String name;
+	QPoint lastPoint;
+	int nameVersion = 0;
+};
+
 class Element
 	: public Object
 	, public RuntimeComposer<Element>
@@ -254,6 +263,7 @@ public:
 		SpecialOnlyEmoji = 0x0080,
 		CustomEmojiRepainting = 0x0100,
 		ScheduledUntilOnline = 0x0200,
+		TopicRootReply = 0x0400,
 	};
 	using Flags = base::flags<Flag>;
 	friend inline constexpr auto is_flag_type(Flag) { return true; }
@@ -290,6 +300,8 @@ public:
 	[[nodiscard]] bool isBubbleAttachedToPrevious() const;
 	[[nodiscard]] bool isBubbleAttachedToNext() const;
 
+	[[nodiscard]] bool isTopicRootReply() const;
+
 	[[nodiscard]] int skipBlockWidth() const;
 	[[nodiscard]] int skipBlockHeight() const;
 	[[nodiscard]] virtual int infoWidth() const;
@@ -373,6 +385,7 @@ public:
 	[[nodiscard]] virtual bool displayFromPhoto() const;
 	[[nodiscard]] virtual bool hasFromName() const;
 	[[nodiscard]] virtual bool displayFromName() const;
+	[[nodiscard]] virtual TopicButton *displayedTopicButton() const;
 	[[nodiscard]] virtual bool displayForwardedFrom() const;
 	[[nodiscard]] virtual bool hasOutLayout() const;
 	[[nodiscard]] virtual bool drawBubble() const;
@@ -390,7 +403,8 @@ public:
 		int left,
 		int top,
 		int outerWidth) const;
-	[[nodiscard]] virtual ClickHandlerPtr rightActionLink() const;
+	[[nodiscard]] virtual ClickHandlerPtr rightActionLink(
+		std::optional<QPoint> pressPoint) const;
 	[[nodiscard]] virtual TimeId displayedEditDate() const;
 	[[nodiscard]] virtual bool hasVisibleText() const;
 	[[nodiscard]] virtual HistoryMessageReply *displayedReply() const;
@@ -497,6 +511,7 @@ protected:
 
 	void clearSpecialOnlyEmoji();
 	void checkSpecialOnlyEmoji();
+	void refreshIsTopicRootReply();
 
 private:
 	// This should be called only from previousInBlocksChanged()
@@ -510,6 +525,8 @@ private:
 	// HistoryView::Element::Flag::AttachedToPrevious.
 	void recountAttachToPreviousInBlocks();
 
+	[[nodiscard]] bool countIsTopicRootReply() const;
+
 	QSize countOptimalSize() final override;
 	QSize countCurrentSize(int newWidth) final override;
 
