@@ -112,6 +112,11 @@ public:
 	}
 	[[nodiscard]] rpl::producer<> searchRequest() const;
 
+	void setGeometryWithNarrowRatio(
+		QRect geometry,
+		int narrowWidth,
+		float64 narrowRatio);
+
 protected:
 	void paintEvent(QPaintEvent *e) override;
 	void mousePressEvent(QMouseEvent *e) override;
@@ -129,6 +134,7 @@ private:
 	void updateControlsGeometry();
 	void slideAnimationCallback();
 	void updateInfoToggleActive();
+	void setupDragOnBackButton();
 
 	void call();
 	void groupCall();
@@ -226,12 +232,14 @@ private:
 	object_ptr<TWidget> _membersShowArea = { nullptr };
 	rpl::event_stream<bool> _membersShowAreaActive;
 
+	float64 _narrowRatio = 0.;
+	int _narrowWidth = 0;
+
 	Ui::Text::String _titlePeerText;
 	bool _titlePeerTextOnline = false;
 	int _leftTaken = 0;
 	int _rightTaken = 0;
 	bool _animatingMode = false;
-	bool _narrowMode = false;
 	std::unique_ptr<Ui::InfiniteRadialAnimation> _connecting;
 
 	SendActionPainter *_sendAction = nullptr;
@@ -245,6 +253,8 @@ private:
 	rpl::event_stream<> _clearSelection;
 	rpl::event_stream<> _cancelChooseForReport;
 
+	rpl::lifetime _backLifetime;
+
 };
 
 } // namespace HistoryView
