@@ -1032,16 +1032,32 @@ TextState Gif::textState(QPoint point, StateRequest request) const {
 					+ st::msgDateImgPadding.y();
 			}
 			if (QRect(QPoint(fastShareLeft, fastShareTop), *size).contains(point)) {
-				result.link = _parent->rightActionLink();
+				result.link = _parent->rightActionLink(point
+					- QPoint(fastShareLeft, fastShareTop));
 			}
 		}
-		if (_transcribe && _transcribe->lastPaintedRect().contains(point)) {
+		if (_transcribe && _transcribe->contains(point)) {
 			result.link = _transcribe->link();
 		}
 	}
 	return result;
 }
 
+void Gif::clickHandlerPressedChanged(
+		const ClickHandlerPtr &handler,
+		bool pressed) {
+	File::clickHandlerPressedChanged(handler, pressed);
+	if (!handler) {
+		return;
+	} else if (_transcribe && (handler == _transcribe->link())) {
+		if (pressed) {
+			_transcribe->addRipple([=] { repaint(); });
+		} else {
+			_transcribe->stopRipple();
+		}
+	}
+}
+
 TextForMimeData Gif::selectedText(TextSelection selection) const {
 	return _caption.toTextForMimeData(selection);
 }
@@ -1308,7 +1324,8 @@ bool Gif::needsBubble() const {
 		|| item->viaBot()
 		|| _parent->displayedReply()
 		|| _parent->displayForwardedFrom()
-		|| _parent->displayFromName();
+		|| _parent->displayFromName()
+		|| _parent->displayedTopicButton();
 	return false;
 }
 
