@@ -50,6 +50,10 @@ public:
 	void draw(Painter &p, const PaintContext &context) const override;
 	TextState textState(QPoint point, StateRequest request) const override;
 
+	void clickHandlerPressedChanged(
+		const ClickHandlerPtr &p,
+		bool pressed) override;
+
 	[[nodiscard]] TextSelection adjustSelection(
 			TextSelection selection,
 			TextSelectType type) const override {
