@@ -474,7 +474,7 @@ MTPVector<MTPDocumentAttribute> Result::adjustAttributes(
 	const auto mime = qs(mimeType);
 	if (_type == Type::Gif) {
 		if (!exists(mtpc_documentAttributeFilename)) {
-			auto filename = (mime == qstr("video/mp4")
+			auto filename = (mime == u"video/mp4"_q
 				? "animation.gif.mp4"
 				: "animation.gif");
 			result.push_back(MTP_documentAttributeFilename(
@@ -487,7 +487,7 @@ MTPVector<MTPDocumentAttribute> Result::adjustAttributes(
 		const auto audio = find(mtpc_documentAttributeAudio);
 		if (audio != result.cend()) {
 			using Flag = MTPDdocumentAttributeAudio::Flag;
-			if (mime == qstr("audio/ogg")) {
+			if (mime == u"audio/ogg"_q) {
 				// We always treat audio/ogg as a voice message.
 				// It was that way before we started to get attributes here.
 				const auto &fields = audio->c_documentAttributeAudio();
@@ -507,10 +507,10 @@ MTPVector<MTPDocumentAttribute> Result::adjustAttributes(
 				const auto p = Core::MimeTypeForName(mime).globPatterns();
 				auto pattern = p.isEmpty() ? QString() : p.front();
 				const auto extension = pattern.isEmpty()
-					? qsl(".unknown")
+					? u".unknown"_q
 					: pattern.replace('*', QString());
 				const auto filename = filedialogDefaultName(
-					qsl("inline"),
+					u"inline"_q,
 					extension,
 					QString(),
 					true);
