@@ -145,15 +145,15 @@ void PasswordCheckWidget::pwdSubmitFail(const MTP::Error &error) {
 
 	_sentRequest = 0;
 	const auto &type = error.type();
-	if (type == qstr("PASSWORD_HASH_INVALID")
-		|| type == qstr("SRP_PASSWORD_CHANGED")) {
+	if (type == u"PASSWORD_HASH_INVALID"_q
+		|| type == u"SRP_PASSWORD_CHANGED"_q) {
 		showError(tr::lng_signin_bad_password());
 		_pwdField->selectAll();
 		_pwdField->showError();
-	} else if (type == qstr("PASSWORD_EMPTY")
-		|| type == qstr("AUTH_KEY_UNREGISTERED")) {
+	} else if (type == u"PASSWORD_EMPTY"_q
+		|| type == u"AUTH_KEY_UNREGISTERED"_q) {
 		goBack();
-	} else if (type == qstr("SRP_ID_INVALID")) {
+	} else if (type == u"SRP_ID_INVALID"_q) {
 		handleSrpIdInvalid();
 	} else {
 		if (Logs::DebugEnabled()) { // internal server error
@@ -251,15 +251,15 @@ void PasswordCheckWidget::codeSubmitFail(const MTP::Error &error) {
 
 	_sentRequest = 0;
 	const auto &type = error.type();
-	if (type == qstr("PASSWORD_EMPTY")
-		|| type == qstr("AUTH_KEY_UNREGISTERED")) {
+	if (type == u"PASSWORD_EMPTY"_q
+		|| type == u"AUTH_KEY_UNREGISTERED"_q) {
 		goBack();
-	} else if (type == qstr("PASSWORD_RECOVERY_NA")) {
+	} else if (type == u"PASSWORD_RECOVERY_NA"_q) {
 		recoverStartFail(error);
-	} else if (type == qstr("PASSWORD_RECOVERY_EXPIRED")) {
+	} else if (type == u"PASSWORD_RECOVERY_EXPIRED"_q) {
 		_emailPattern = QString();
 		toPassword();
-	} else if (type == qstr("CODE_INVALID")) {
+	} else if (type == u"CODE_INVALID"_q) {
 		showError(tr::lng_signin_wrong_code());
 		_codeField->selectAll();
 		_codeField->showError();
