@@ -314,14 +314,17 @@ void Step::fillSentCodeData(const MTPDauth_sentCode &data) {
 	const auto bad = [](const char *type) {
 		LOG(("API Error: Should not be '%1'.").arg(type));
 	};
+	getData()->codeByTelegram = false;
+	getData()->codeByFragmentUrl = QString();
 	data.vtype().match([&](const MTPDauth_sentCodeTypeApp &data) {
 		getData()->codeByTelegram = true;
 		getData()->codeLength = data.vlength().v;
 	}, [&](const MTPDauth_sentCodeTypeSms &data) {
-		getData()->codeByTelegram = false;
+		getData()->codeLength = data.vlength().v;
+	}, [&](const MTPDauth_sentCodeTypeFragmentSms &data) {
+		getData()->codeByFragmentUrl = qs(data.vurl());
 		getData()->codeLength = data.vlength().v;
 	}, [&](const MTPDauth_sentCodeTypeCall &data) {
-		getData()->codeByTelegram = false;
 		getData()->codeLength = data.vlength().v;
 	}, [&](const MTPDauth_sentCodeTypeFlashCall &) {
 		bad("FlashCall");
