@@ -30,6 +30,7 @@ class FadeWrap;
 namespace Window {
 class ConnectionState;
 class Controller;
+class SlideAnimation;
 } // namespace Window
 
 namespace Intro {
@@ -55,6 +56,7 @@ struct Data {
 
 	int codeLength = 5;
 	bool codeByTelegram = false;
+	QString codeByFragmentUrl;
 
 	Core::CloudPasswordState pwdState;
 
@@ -95,15 +97,14 @@ public:
 		not_null<Window::Controller*> controller,
 		not_null<Main::Account*> account,
 		EnterPoint point);
+	~Widget();
 
-	void showAnimated(const QPixmap &bgAnimCache, bool back = false);
+	void showAnimated(QPixmap oldContentCache, bool back = false);
 
 	void setInnerFocus();
 
 	[[nodiscard]] rpl::producer<> showSettingsRequested() const;
 
-	~Widget();
-
 protected:
 	void paintEvent(QPaintEvent *e) override;
 	void resizeEvent(QResizeEvent *e) override;
@@ -111,7 +112,7 @@ protected:
 
 private:
 	void refreshLang();
-	void animationCallback();
+	void showFinished();
 	void createLanguageLink();
 	void checkUpdateStatus();
 	void setupNextButton();
@@ -174,9 +175,7 @@ private:
 	std::optional<MTP::Sender> _api;
 	mtpRequestId _nearestDcRequestId = 0;
 
-	Ui::Animations::Simple _a_show;
-	bool _showBack = false;
-	QPixmap _cacheUnder, _cacheOver;
+	std::unique_ptr<Window::SlideAnimation> _showAnimation;
 
 	std::vector<details::Step*> _stepHistory;
 	rpl::lifetime _stepLifetime;
