@@ -19,7 +19,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 namespace Lang {
 namespace {
 
-const auto kSerializeVersionTag = qsl("#new");
+const auto kSerializeVersionTag = u"#new"_q;
 constexpr auto kSerializeVersion = 1;
 constexpr auto kDefaultLanguage = "en"_cs;
 constexpr auto kCloudLangPackName = "tdesktop"_cs;
@@ -231,11 +231,11 @@ QString CustomLanguageId() {
 
 Language DefaultLanguage() {
 	return Language{
-		qsl("en"),
+		u"en"_q,
 		QString(),
 		QString(),
-		qsl("English"),
-		qsl("English"),
+		u"English"_q,
+		u"English"_q,
 	};
 }
 
@@ -254,7 +254,7 @@ Instance::Instance(not_null<Instance*> derived, const PrivateTag &)
 
 void Instance::switchToId(const Language &data) {
 	reset(data);
-	if (_id == qstr("#TEST_X") || _id == qstr("#TEST_0")) {
+	if (_id == u"#TEST_X"_q || _id == u"#TEST_0"_q) {
 		for (auto &value : _values) {
 			value = PrepareTestValue(value, _id[5]);
 		}
@@ -365,8 +365,8 @@ QString Instance::id(Pack pack) const {
 
 bool Instance::isCustom() const {
 	return (_id == CustomLanguageId())
-		|| (_id == qstr("#TEST_X"))
-		|| (_id == qstr("#TEST_0"));
+		|| (_id == u"#TEST_X"_q)
+		|| (_id == u"#TEST_0"_q);
 }
 
 int Instance::version(Pack pack) const {
