@@ -59,8 +59,8 @@ constexpr auto kTmpPasswordReserveTime = TimeId(10);
 	// Like 'https://telegram.me/' or 'https://t.me/'.
 	const auto &domain = session->serverConfig().internalLinksDomain;
 	const auto prefixes = {
-		qstr("https://"),
-		qstr("http://"),
+		u"https://"_q,
+		u"http://"_q,
 	};
 	for (const auto &prefix : prefixes) {
 		if (domain.startsWith(prefix, Qt::CaseInsensitive)) {
@@ -110,8 +110,9 @@ Session::Session(
 		_user,
 		Data::PeerUpdate::Flag::Photo
 	) | rpl::start_with_next([=] {
-		[[maybe_unused]] const auto image = _user->currentUserpic(
-			_selfUserpicView);
+		auto view = Ui::PeerUserpicView{ .cloud = _selfUserpicView };
+		[[maybe_unused]] const auto image = _user->userpicCloudImage(view);
+		_selfUserpicView = view.cloud;
 	}, lifetime());
 
 	crl::on_main(this, [=] {
@@ -363,8 +364,8 @@ TextWithEntities Session::createInternalLink(
 		const TextWithEntities &query) const {
 	const auto result = createInternalLinkFull(query);
 	const auto prefixes = {
-		qstr("https://"),
-		qstr("http://"),
+		u"https://"_q,
+		u"http://"_q,
 	};
 	for (auto &prefix : prefixes) {
 		if (result.text.startsWith(prefix, Qt::CaseInsensitive)) {
@@ -466,6 +467,11 @@ Window::SessionController *Session::tryResolveWindow() const {
 			return nullptr;
 		}
 	}
+	for (const auto &window : _windows) {
+		if (window->isPrimary()) {
+			return window;
+		}
+	}
 	return _windows.front();
 }
 
