@@ -44,24 +44,24 @@ constexpr auto kShortPollTimeout = crl::time(3000);
 constexpr auto kRememberCredentialsDelay = crl::time(1800 * 1000);
 
 bool ForwardServiceErrorRequired(const QString &error) {
-	return (error == qstr("BOT_INVALID"))
-		|| (error == qstr("PUBLIC_KEY_REQUIRED"))
-		|| (error == qstr("PUBLIC_KEY_INVALID"))
-		|| (error == qstr("SCOPE_EMPTY"))
-		|| (error == qstr("PAYLOAD_EMPTY"));
+	return (error == u"BOT_INVALID"_q)
+		|| (error == u"PUBLIC_KEY_REQUIRED"_q)
+		|| (error == u"PUBLIC_KEY_INVALID"_q)
+		|| (error == u"SCOPE_EMPTY"_q)
+		|| (error == u"PAYLOAD_EMPTY"_q);
 }
 
 bool SaveErrorRequiresRestart(const QString &error) {
-	return (error == qstr("PASSWORD_REQUIRED"))
-		|| (error == qstr("SECURE_SECRET_REQUIRED"))
-		|| (error == qstr("SECURE_SECRET_INVALID"));
+	return (error == u"PASSWORD_REQUIRED"_q)
+		|| (error == u"SECURE_SECRET_REQUIRED"_q)
+		|| (error == u"SECURE_SECRET_INVALID"_q);
 }
 
 bool AcceptErrorRequiresRestart(const QString &error) {
-	return (error == qstr("PASSWORD_REQUIRED"))
-		|| (error == qstr("SECURE_SECRET_REQUIRED"))
-		|| (error == qstr("SECURE_VALUE_EMPTY"))
-		|| (error == qstr("SECURE_VALUE_HASH_INVALID"));
+	return (error == u"PASSWORD_REQUIRED"_q)
+		|| (error == u"SECURE_SECRET_REQUIRED"_q)
+		|| (error == u"SECURE_VALUE_EMPTY"_q)
+		|| (error == u"SECURE_VALUE_HASH_INVALID"_q);
 }
 
 std::map<QString, QString> GetTexts(const ValueMap &map) {
@@ -268,10 +268,9 @@ auto ParseConfig(const QByteArray &json) {
 } // namespace
 
 QString NonceNameByScope(const QString &scope) {
-	if (scope.startsWith('{') && scope.endsWith('}')) {
-		return qsl("nonce");
-	}
-	return qsl("payload");
+	return (scope.startsWith('{') && scope.endsWith('}'))
+		? u"nonce"_q
+		: u"payload"_q;
 }
 
 bool ValueChanged(not_null<const Value*> value, const ValueMap &data) {
@@ -884,7 +883,7 @@ void FormController::submitPassword(
 		}
 	}).fail([=](const MTP::Error &error) {
 		_passwordCheckRequestId = 0;
-		if (error.type() == qstr("SRP_ID_INVALID")) {
+		if (error.type() == u"SRP_ID_INVALID"_q) {
 			handleSrpIdInvalid(_passwordCheckRequestId);
 		} else if (submitSaved) {
 			// Force reload and show form.
@@ -892,8 +891,8 @@ void FormController::submitPassword(
 			reloadPassword();
 		} else if (MTP::IsFloodError(error)) {
 			_passwordError.fire(tr::lng_flood_error(tr::now));
-		} else if (error.type() == qstr("PASSWORD_HASH_INVALID")
-			|| error.type() == qstr("SRP_PASSWORD_CHANGED")) {
+		} else if (error.type() == u"PASSWORD_HASH_INVALID"_q
+			|| error.type() == u"SRP_PASSWORD_CHANGED"_q) {
 			_passwordError.fire(tr::lng_passport_password_wrong(tr::now));
 		} else {
 			_passwordError.fire_copy(error.type());
@@ -963,7 +962,7 @@ void FormController::checkSavedPasswordSettings(
 		}
 	}).fail([=](const MTP::Error &error) {
 		_passwordCheckRequestId = 0;
-		if (error.type() != qstr("SRP_ID_INVALID")
+		if (error.type() != u"SRP_ID_INVALID"_q
 			|| !handleSrpIdInvalid(_passwordCheckRequestId)) {
 		} else {
 			session().data().forgetPassportCredentials();
@@ -1126,7 +1125,7 @@ void FormController::resetSecret(
 		generateSecret(password);
 	}).fail([=](const MTP::Error &error) {
 		_saveSecretRequestId = 0;
-		if (error.type() != qstr("SRP_ID_INVALID")
+		if (error.type() != u"SRP_ID_INVALID"_q
 			|| !handleSrpIdInvalid(_saveSecretRequestId)) {
 			formFail(error.type());
 		}
@@ -1709,7 +1708,7 @@ void FormController::verify(
 				clearValueVerification(nonconst);
 			}).fail([=](const MTP::Error &error) {
 				nonconst->verification.requestId = 0;
-				if (error.type() == qstr("PHONE_CODE_INVALID")) {
+				if (error.type() == u"PHONE_CODE_INVALID"_q) {
 					verificationError(
 						nonconst,
 						tr::lng_signin_wrong_code(tr::now));
@@ -1726,7 +1725,7 @@ void FormController::verify(
 				clearValueVerification(nonconst);
 			}).fail([=](const MTP::Error &error) {
 				nonconst->verification.requestId = 0;
-				if (error.type() == qstr("CODE_INVALID")) {
+				if (error.type() == u"CODE_INVALID"_q) {
 					verificationError(
 						nonconst,
 						tr::lng_signin_wrong_code(tr::now));
@@ -2107,24 +2106,24 @@ void FormController::sendSaveRequest(
 		value->saveRequestId = 0;
 		const auto code = error.type();
 		if (handleAppUpdateError(code)) {
-		} else if (code == qstr("PHONE_VERIFICATION_NEEDED")) {
+		} else if (code == u"PHONE_VERIFICATION_NEEDED"_q) {
 			if (value->type == Value::Type::Phone) {
 				startPhoneVerification(value);
 				return;
 			}
-		} else if (code == qstr("PHONE_NUMBER_INVALID")) {
+		} else if (code == u"PHONE_NUMBER_INVALID"_q) {
 			if (value->type == Value::Type::Phone) {
 				value->data.parsedInEdit.fields["value"].error
 					= tr::lng_bad_phone(tr::now);
 				valueSaveFailed(value);
 				return;
 			}
-		} else if (code == qstr("EMAIL_VERIFICATION_NEEDED")) {
+		} else if (code == u"EMAIL_VERIFICATION_NEEDED"_q) {
 			if (value->type == Value::Type::Email) {
 				startEmailVerification(value);
 				return;
 			}
-		} else if (code == qstr("EMAIL_INVALID")) {
+		} else if (code == u"EMAIL_INVALID"_q) {
 			if (value->type == Value::Type::Email) {
 				value->data.parsedInEdit.fields["value"].error
 					= tr::lng_cloud_password_bad_email(tr::now);
@@ -2174,6 +2173,7 @@ void FormController::startPhoneVerification(not_null<Value*> value) {
 			const auto timeout = data.vtimeout();
 			value->verification.requestId = 0;
 			value->verification.phoneCodeHash = qs(data.vphone_code_hash());
+			value->verification.fragmentUrl = QString();
 			const auto bad = [](const char *type) {
 				LOG(("API Error: Should not be '%1' "
 					"in FormController::startPhoneVerification.").arg(type));
@@ -2206,6 +2206,10 @@ void FormController::startPhoneVerification(not_null<Value*> value) {
 						timeout.value_or(60),
 					});
 				}
+			}, [&](const MTPDauth_sentCodeTypeFragmentSms &data) {
+				value->verification.codeLength = data.vlength().v;
+				value->verification.fragmentUrl = qs(data.vurl());
+				value->verification.call = nullptr;
 			}, [&](const MTPDauth_sentCodeTypeFlashCall &) {
 				bad("FlashCall");
 			}, [&](const MTPDauth_sentCodeTypeMissedCall &) {
@@ -2325,7 +2329,7 @@ void FormController::saveSecret(
 		}
 	}).fail([=](const MTP::Error &error) {
 		_saveSecretRequestId = 0;
-		if (error.type() != qstr("SRP_ID_INVALID")
+		if (error.type() != u"SRP_ID_INVALID"_q
 			|| !handleSrpIdInvalid(_saveSecretRequestId)) {
 			suggestRestart();
 		}
@@ -2608,7 +2612,7 @@ void FormController::formFail(const QString &error) {
 }
 
 bool FormController::handleAppUpdateError(const QString &error) {
-	if (error == qstr("APP_VERSION_OUTDATED")) {
+	if (error == u"APP_VERSION_OUTDATED"_q) {
 		_view->showUpdateAppBox();
 		return true;
 	}
