@@ -128,9 +128,9 @@ EditDocumentScheme GetDocumentScheme(
 		return result.isEmpty() ? value : result;
 	};
 	const auto GenderFormat = [](const QString &value) {
-		if (value == qstr("male")) {
+		if (value == u"male"_q) {
 			return tr::lng_passport_gender_male(tr::now);
-		} else if (value == qstr("female")) {
+		} else if (value == u"female"_q) {
 			return tr::lng_passport_gender_female(tr::now);
 		}
 		return value;
@@ -179,7 +179,7 @@ EditDocumentScheme GetDocumentScheme(
 		return value.isEmpty() || DateValidateBoolean(value);
 	});
 	const auto GenderValidate = FromBoolean([](const QString &value) {
-		return value == qstr("male") || value == qstr("female");
+		return value == u"male"_q || value == u"female"_q;
 	});
 	const auto CountryValidate = FromBoolean([=](const QString &value) {
 		return !CountryFormat(value).isEmpty();
@@ -217,7 +217,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("first_name"),
+				"first_name"_q,
 				tr::lng_passport_first_name(tr::now),
 				NameValidate,
 				DontFormat,
@@ -226,27 +226,27 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("middle_name"),
+				"middle_name"_q,
 				tr::lng_passport_middle_name(tr::now),
 				NameOrEmptyValidate,
 				DontFormat,
 				kMaxNameSize,
-				qsl("first_name"),
+				"first_name"_q,
 			},
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("last_name"),
+				"last_name"_q,
 				tr::lng_passport_last_name(tr::now),
 				NameValidate,
 				DontFormat,
 				kMaxNameSize,
-				qsl("first_name"),
+				"first_name"_q,
 			},
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Date,
-				qsl("birth_date"),
+				"birth_date"_q,
 				tr::lng_passport_birth_date(tr::now),
 				DateValidate,
 				DontFormat,
@@ -254,7 +254,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Gender,
-				qsl("gender"),
+				"gender"_q,
 				tr::lng_passport_gender(tr::now),
 				GenderValidate,
 				GenderFormat,
@@ -262,7 +262,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Country,
-				qsl("country_code"),
+				"country_code"_q,
 				tr::lng_passport_country(tr::now),
 				CountryValidate,
 				CountryFormat,
@@ -270,7 +270,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Country,
-				qsl("residence_country_code"),
+				"residence_country_code"_q,
 				tr::lng_passport_residence_country(tr::now),
 				CountryValidate,
 				CountryFormat,
@@ -278,7 +278,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Scans,
 				Ui::PanelDetailsType::Text,
-				qsl("document_no"),
+				"document_no"_q,
 				tr::lng_passport_document_number(tr::now),
 				DocumentValidate,
 				DontFormat,
@@ -287,14 +287,14 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Scans,
 				Ui::PanelDetailsType::Date,
-				qsl("expiry_date"),
+				"expiry_date"_q,
 				tr::lng_passport_expiry_date(tr::now),
 				DateOrEmptyValidate,
 				DontFormat,
 			},
 		};
 		if (nativeNames) {
-			result.additionalDependencyKey = qsl("residence_country_code");
+			result.additionalDependencyKey = "residence_country_code"_q;
 
 			result.preferredLanguage = preferredLanguage
 				? std::move(preferredLanguage)
@@ -342,35 +342,35 @@ EditDocumentScheme GetDocumentScheme(
 				{
 					ValueClass::Additional,
 					Ui::PanelDetailsType::Text,
-					qsl("first_name_native"),
+					"first_name_native"_q,
 					tr::lng_passport_first_name(tr::now),
 					NativeNameValidate,
 					DontFormat,
 					kMaxNameSize,
 					QString(),
-					qsl("first_name"),
+					"first_name"_q,
 				},
 				{
 					ValueClass::Additional,
 					Ui::PanelDetailsType::Text,
-					qsl("middle_name_native"),
+					"middle_name_native"_q,
 					tr::lng_passport_middle_name(tr::now),
 					NativeNameOrEmptyValidate,
 					DontFormat,
 					kMaxNameSize,
-					qsl("first_name_native"),
-					qsl("middle_name"),
+					"first_name_native"_q,
+					"middle_name"_q,
 				},
 				{
 					ValueClass::Additional,
 					Ui::PanelDetailsType::Text,
-					qsl("last_name_native"),
+					"last_name_native"_q,
 					tr::lng_passport_last_name(tr::now),
 					NativeNameValidate,
 					DontFormat,
 					kMaxNameSize,
-					qsl("first_name_native"),
-					qsl("last_name"),
+					"first_name_native"_q,
+					"last_name"_q,
 				},
 			};
 			for (auto &row : additional) {
@@ -409,7 +409,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("street_line1"),
+				"street_line1"_q,
 				tr::lng_passport_street(tr::now),
 				StreetValidate,
 				DontFormat,
@@ -418,7 +418,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("street_line2"),
+				"street_line2"_q,
 				tr::lng_passport_street(tr::now),
 				DontValidate,
 				DontFormat,
@@ -427,7 +427,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("city"),
+				"city"_q,
 				tr::lng_passport_city(tr::now),
 				CityValidate,
 				DontFormat,
@@ -436,7 +436,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Text,
-				qsl("state"),
+				"state"_q,
 				tr::lng_passport_state(tr::now),
 				DontValidate,
 				DontFormat,
@@ -445,7 +445,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Country,
-				qsl("country_code"),
+				"country_code"_q,
 				tr::lng_passport_country(tr::now),
 				CountryValidate,
 				CountryFormat,
@@ -453,7 +453,7 @@ EditDocumentScheme GetDocumentScheme(
 			{
 				ValueClass::Fields,
 				Ui::PanelDetailsType::Postcode,
-				qsl("post_code"),
+				"post_code"_q,
 				tr::lng_passport_postcode(tr::now),
 				PostcodeValidate,
 				DontFormat,
@@ -512,18 +512,18 @@ EditContactScheme GetContactScheme(Scope::Type type) {
 
 const std::map<QString, QString> &LatinToNativeMap() {
 	static const auto result = std::map<QString, QString> {
-		{ qsl("first_name"), qsl("first_name_native") },
-		{ qsl("last_name"), qsl("last_name_native") },
-		{ qsl("middle_name"), qsl("middle_name_native") },
+		{ "first_name"_q, "first_name_native"_q },
+		{ "last_name"_q, "last_name_native"_q },
+		{ "middle_name"_q, "middle_name_native"_q },
 	};
 	return result;
 }
 
 const std::map<QString, QString> &NativeToLatinMap() {
 	static const auto result = std::map<QString, QString> {
-		{ qsl("first_name_native"), qsl("first_name") },
-		{ qsl("last_name_native"), qsl("last_name") },
-		{ qsl("middle_name_native"), qsl("middle_name") },
+		{ "first_name_native"_q, "first_name"_q },
+		{ "last_name_native"_q, "last_name"_q },
+		{ "middle_name_native"_q, "middle_name"_q },
 	};
 	return result;
 }
