@@ -26,6 +26,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "smartglocal/smartglocal_token.h"
 #include "storage/storage_account.h"
 #include "ui/image/image.h"
+#include "ui/text/text_entity.h"
 #include "apiwrap.h"
 #include "core/core_cloud_password.h"
 #include "window/themes/window_theme.h"
@@ -313,10 +314,20 @@ void Form::processForm(const MTPDpayments_paymentForm &data) {
 			processSavedInformation(data);
 		});
 	}
+	_paymentMethod.savedCredentials.clear();
+	_paymentMethod.savedCredentialsIndex = 0;
 	if (const auto credentials = data.vsaved_credentials()) {
-		credentials->match([&](const auto &data) {
-			processSavedCredentials(data);
-		});
+		_paymentMethod.savedCredentials.reserve(credentials->v.size());
+		for (const auto &saved : credentials->v) {
+			_paymentMethod.savedCredentials.push_back({
+				.id = qs(saved.data().vid()),
+				.title = qs(saved.data().vtitle()),
+			});
+		}
+		refreshPaymentMethodDetails();
+	}
+	if (const auto additional = data.vadditional_methods()) {
+		processAdditionalPaymentMethods(additional->v);
 	}
 	fillPaymentMethodInformation();
 	_updates.fire(FormReady{});
@@ -340,10 +351,11 @@ void Form::processReceipt(const MTPDpayments_paymentReceipt &data) {
 			_shippingOptions.selectedId = _shippingOptions.list.front().id;
 		}
 	}
-	_paymentMethod.savedCredentials = SavedCredentials{
+	_paymentMethod.savedCredentials = { {
 		.id = "(used)",
 		.title = qs(data.vcredentials_title()),
-	};
+	} };
+	_paymentMethod.savedCredentialsIndex = 0;
 	fillPaymentMethodInformation();
 	_updates.fire(FormReady{});
 }
@@ -397,7 +409,9 @@ void Form::processDetails(const MTPDpayments_paymentForm &data) {
 		.passwordMissing = data.is_password_missing(),
 	};
 	_invoice.cover.title = qs(data.vtitle());
-	_invoice.cover.description = qs(data.vdescription());
+	_invoice.cover.description = TextUtilities::ParseEntities(
+		qs(data.vdescription()),
+		TextParseLinks | TextParseMultiline);
 	if (_invoice.cover.thumbnail.isNull() && !_thumbnailLoadProcess) {
 		if (const auto photo = data.vphoto()) {
 			loadThumbnail(
@@ -406,13 +420,13 @@ void Form::processDetails(const MTPDpayments_paymentForm &data) {
 	}
 	if (const auto botId = _details.botId) {
 		if (const auto bot = _session->data().userLoaded(botId)) {
-			_invoice.cover.seller = bot->name;
-			_details.termsBotUsername = bot->username;
+			_invoice.cover.seller = bot->name();
+			_details.termsBotUsername = bot->username();
 		}
 	}
 	if (const auto providerId = _details.providerId) {
 		if (const auto bot = _session->data().userLoaded(providerId)) {
-			_invoice.provider = bot->name;
+			_invoice.provider = bot->name();
 		}
 	}
 }
@@ -429,12 +443,12 @@ void Form::processDetails(const MTPDpayments_paymentReceipt &data) {
 		.providerId = data.vprovider_id().v,
 	};
 	if (_invoice.cover.title.isEmpty()
-		&& _invoice.cover.description.isEmpty()
+		&& _invoice.cover.description.empty()
 		&& _invoice.cover.thumbnail.isNull()
 		&& !_thumbnailLoadProcess) {
 		_invoice.cover = Ui::Cover{
 			.title = qs(data.vtitle()),
-			.description = qs(data.vdescription()),
+			.description = { qs(data.vdescription()) },
 		};
 		if (const auto web = data.vphoto()) {
 			if (const auto photo = _session->data().photoFromWeb(*web, {})) {
@@ -444,7 +458,7 @@ void Form::processDetails(const MTPDpayments_paymentReceipt &data) {
 	}
 	if (_details.botId) {
 		if (const auto bot = _session->data().userLoaded(_details.botId)) {
-			_invoice.cover.seller = bot->name;
+			_invoice.cover.seller = bot->name();
 		}
 	}
 }
@@ -461,27 +475,46 @@ void Form::processSavedInformation(const MTPDpaymentRequestedInfo &data) {
 	};
 }
 
-void Form::processSavedCredentials(
-		const MTPDpaymentSavedCredentialsCard &data) {
-	_paymentMethod.savedCredentials = SavedCredentials{
-		.id = qs(data.vid()),
-		.title = qs(data.vtitle()),
-	};
-	refreshPaymentMethodDetails();
+void Form::processAdditionalPaymentMethods(
+		const QVector<MTPPaymentFormMethod> &list) {
+	_paymentMethod.ui.additionalMethods = ranges::views::all(
+		list
+	) | ranges::views::transform([](const MTPPaymentFormMethod &method) {
+		return Ui::PaymentMethodAdditional{
+			.title = qs(method.data().vtitle()),
+			.url = qs(method.data().vurl()),
+		};
+	}) | ranges::to_vector;
 }
 
 void Form::refreshPaymentMethodDetails() {
-	const auto &saved = _paymentMethod.savedCredentials;
-	const auto &entered = _paymentMethod.newCredentials;
-	_paymentMethod.ui.title = entered ? entered.title : saved.title;
+	refreshSavedPaymentMethodDetails();
 	_paymentMethod.ui.provider = _invoice.provider;
-	_paymentMethod.ui.ready = entered || saved;
 	_paymentMethod.ui.native.defaultCountry = defaultCountry();
 	_paymentMethod.ui.canSaveInformation
 		= _paymentMethod.ui.native.canSaveInformation
 		= _details.canSaveCredentials || _details.passwordMissing;
 }
 
+void Form::refreshSavedPaymentMethodDetails() {
+	const auto &list = _paymentMethod.savedCredentials;
+	const auto index = _paymentMethod.savedCredentialsIndex;
+	const auto &entered = _paymentMethod.newCredentials;
+	_paymentMethod.ui.savedMethods.clear();
+	if (entered) {
+		_paymentMethod.ui.savedMethods.push_back({ .title = entered.title });
+	}
+	for (const auto &item : list) {
+		_paymentMethod.ui.savedMethods.push_back({
+			.id = item.id,
+			.title = item.title,
+		});
+	}
+	_paymentMethod.ui.savedMethodIndex = (index < list.size())
+		? (index + (entered ? 1 : 0))
+		: 0;
+}
+
 QString Form::defaultPhone() const {
 	return _session->user()->phone();
 }
@@ -570,12 +603,16 @@ void Form::fillSmartGlocalNativeMethod(QJsonObject object) {
 
 void Form::submit() {
 	Expects(_paymentMethod.newCredentials
-		|| _paymentMethod.savedCredentials);
+		|| (_paymentMethod.savedCredentialsIndex
+			< _paymentMethod.savedCredentials.size()));
 
-	const auto password = _paymentMethod.newCredentials
-		? QByteArray()
-		: _session->validTmpPassword();
-	if (!_paymentMethod.newCredentials && password.isEmpty()) {
+	const auto index = _paymentMethod.savedCredentialsIndex;
+	const auto &list = _paymentMethod.savedCredentials;
+
+	const auto password = (index < list.size())
+		? _session->validTmpPassword()
+		: QByteArray();
+	if (index < list.size() && password.isEmpty()) {
 		_updates.fire(TmpPasswordRequired{});
 		return;
 	} else if (!_session->local().isBotTrustedPayment(_details.botId)) {
@@ -600,16 +637,16 @@ void Form::submit() {
 		inputInvoice(),
 		MTP_string(_requestedInformationId),
 		MTP_string(_shippingOptions.selectedId),
-		(_paymentMethod.newCredentials
-			? MTP_inputPaymentCredentials(
+		(index < list.size()
+			? MTP_inputPaymentCredentialsSaved(
+				MTP_string(list[index].id),
+				MTP_bytes(password))
+			: MTP_inputPaymentCredentials(
 				MTP_flags((_paymentMethod.newCredentials.saveOnServer
 					&& _details.canSaveCredentials)
 					? MTPDinputPaymentCredentials::Flag::f_save
 					: MTPDinputPaymentCredentials::Flag(0)),
-				MTP_dataJSON(MTP_bytes(_paymentMethod.newCredentials.data)))
-			: MTP_inputPaymentCredentialsSaved(
-				MTP_string(_paymentMethod.savedCredentials.id),
-				MTP_bytes(password))),
+				MTP_dataJSON(MTP_bytes(_paymentMethod.newCredentials.data)))),
 		MTP_long(_invoice.tipsSelected)
 	)).done([=](const MTPpayments_PaymentResult &result) {
 		hideProgress();
@@ -707,7 +744,9 @@ bool Form::hasChanges() const {
 	return (information != _savedInformation)
 		|| (_stripe != nullptr)
 		|| (_smartglocal != nullptr)
-		|| !_paymentMethod.newCredentials.empty();
+		|| (!_paymentMethod.newCredentials.empty()
+			&& (_paymentMethod.savedCredentialsIndex
+				>= _paymentMethod.savedCredentials.size()));
 }
 
 bool Form::validateInformationLocal(
@@ -922,10 +961,30 @@ void Form::setPaymentCredentials(const NewCredentials &credentials) {
 	Expects(!credentials.empty());
 
 	_paymentMethod.newCredentials = credentials;
+	_paymentMethod.savedCredentialsIndex
+		= _paymentMethod.savedCredentials.size();
+	refreshSavedPaymentMethodDetails();
 	const auto requestNewPassword = credentials.saveOnServer
 		&& !_details.canSaveCredentials
 		&& _details.passwordMissing;
-	refreshPaymentMethodDetails();
+	_updates.fire(PaymentMethodUpdate{ requestNewPassword });
+}
+
+void Form::chooseSavedMethod(const QString &id) {
+	auto &index = _paymentMethod.savedCredentialsIndex;
+	const auto &list = _paymentMethod.savedCredentials;
+	if (id.isEmpty() && _paymentMethod.newCredentials) {
+		index = list.size();
+	} else {
+		const auto i = ranges::find(list, id, &SavedCredentials::id);
+		index = (i != end(list)) ? (i - begin(list)) : 0;
+	}
+	refreshSavedPaymentMethodDetails();
+	const auto requestNewPassword = (index == list.size())
+		&& _paymentMethod.newCredentials
+		&& _paymentMethod.newCredentials.saveOnServer
+		&& !_details.canSaveCredentials
+		&& _details.passwordMissing;
 	_updates.fire(PaymentMethodUpdate{ requestNewPassword });
 }
 
