@@ -47,8 +47,8 @@ QByteArray gLocalSalt;
 int gScreenScale = style::kScaleAuto;
 int gConfigScale = style::kScaleAuto;
 
-QString gDateFormat = qsl("dd.MM.yy");
-QString gTimeFormat = qsl("hh:mm");
+QString gDateFormat = u"dd.MM.yy"_q;
+QString gTimeFormat = u"hh:mm"_q;
 
 RecentStickerPreload gRecentStickersPreload;
 RecentStickerPack gRecentStickers;
