@@ -31,10 +31,12 @@ void SetupExport(
 	not_null<Window::SessionController*> controller,
 	not_null<Ui::VerticalLayout*> container);
 
-class Chat : public Section {
+class Chat : public Section<Chat> {
 public:
 	Chat(QWidget *parent, not_null<Window::SessionController*> controller);
 
+	[[nodiscard]] rpl::producer<QString> title() override;
+
 private:
 	void setupContent(not_null<Window::SessionController*> controller);
 
