@@ -9,7 +9,10 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "base/variant.h"
 #include "api/api_common.h"
-#include "ui/chat/attach/attach_prepare.h"
+
+namespace Ui {
+struct PreparedFileInformation;
+} // namespace Ui
 
 namespace Main {
 class Session;
