@@ -106,13 +106,15 @@ struct PreparedList {
 		std::vector<int> order);
 	void mergeToEnd(PreparedList &&other, bool cutToAlbumSize = false);
 
-	[[nodiscard]] bool canAddCaption(bool sendingAlbum) const;
+	[[nodiscard]] bool canAddCaption(bool sendingAlbum, bool compress) const;
 	[[nodiscard]] bool canBeSentInSlowmode() const;
 	[[nodiscard]] bool canBeSentInSlowmodeWith(
 		const PreparedList &other) const;
 
 	[[nodiscard]] bool hasGroupOption(bool slowmode) const;
 	[[nodiscard]] bool hasSendImagesAsPhotosOption(bool slowmode) const;
+	[[nodiscard]] bool canHaveEditorHintLabel() const;
+	[[nodiscard]] bool hasSticker() const;
 
 	Error error = Error::None;
 	QString errorData;
