@@ -23,6 +23,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_session.h"
 #include "main/main_session.h"
 #include "main/main_session_settings.h"
+#include "base/options.h"
+#include "base/call_delayed.h"
 #include "base/crc32hash.h"
 #include "ui/toast/toast.h"
 #include "ui/widgets/shadow.h"
@@ -32,7 +34,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "apiwrap.h"
 #include "mainwindow.h"
 #include "mainwidget.h" // session->content()->windowShown().
-#include "facades.h"
 #include "tray.h"
 #include "styles/style_widgets.h"
 #include "styles/style_window.h"
@@ -48,8 +49,16 @@ namespace {
 
 constexpr auto kSaveWindowPositionTimeout = crl::time(1000);
 
+base::options::toggle ShowChatNameInNewWindow({
+	.id = kOptionShowChatNameInNewWindow,
+	.name = "Show chat name in title of separated windows",
+	.description = "",
+});
+
 } // namespace
 
+const char kOptionShowChatNameInNewWindow[] = "show-chat-name-in-new-window";
+
 const QImage &Logo() {
 	static const auto result = QImage(u":/gui/art/logo_256.png"_q);
 	return result;
@@ -375,7 +384,7 @@ bool MainWindow::hideNoQuit() {
 		|| workMode == Core::Settings::WorkMode::WindowAndTray) {
 		if (minimizeToTray()) {
 			if (const auto controller = sessionController()) {
-				Ui::showChatsList(&controller->session());
+				controller->clearSectionStack();
 			}
 			return true;
 		}
@@ -389,7 +398,7 @@ bool MainWindow::hideNoQuit() {
 		controller().updateIsActiveBlur();
 		updateGlobalMenu();
 		if (const auto controller = sessionController()) {
-			Ui::showChatsList(&controller->session());
+			controller->clearSectionStack();
 		}
 		return true;
 	}
@@ -797,8 +806,22 @@ void MainWindow::updateUnreadCounter() {
 		return;
 	}
 
-	const auto counter = Core::App().unreadBadge();
-	setTitle((counter > 0) ? qsl("Telegram (%1)").arg(counter) : qsl("Telegram"));
+	if (ShowChatNameInNewWindow.value() && singlePeer()) {
+		const auto peer = singlePeer();
+		const auto history = peer->owner().history(peer);
+		const auto name = peer->isSelf()
+			? tr::lng_saved_messages(tr::now)
+			: peer->name();
+		const auto counter = history->unreadCount();
+		setTitle((counter > 0)
+			? u"(%1) %2 \u2013 Telegram"_q.arg(QString::number(counter), name)
+			: u"%1 \u2013 Telegram"_q.arg(name));
+	} else {
+		const auto counter = Core::App().unreadBadge();
+		setTitle((counter > 0)
+			? u"Telegram (%1)"_q.arg(counter)
+			: u"Telegram"_q);
+	}
 
 	Core::App().tray().updateIconCounters();
 	unreadCounterChangedHook();
