@@ -25,6 +25,7 @@ constexpr auto kMinContrastDistance = 64 * 64 * 4;
 constexpr auto kContrastDeltaL = 64;
 
 auto PaletteChanges = rpl::event_stream<>();
+auto PaletteVersion = 0;
 auto ShortAnimationRunning = rpl::variable<bool>(false);
 auto RunningShortAnimations = 0;
 
@@ -73,7 +74,12 @@ rpl::producer<> PaletteChanged() {
 	return internal::PaletteChanges.events();
 }
 
+int PaletteVersion() {
+	return internal::PaletteVersion;
+}
+
 void NotifyPaletteChanged() {
+	++internal::PaletteVersion;
 	internal::PaletteChanges.fire({});
 }
 
@@ -144,11 +150,7 @@ namespace internal {
 
 QImage createCircleMask(int size, QColor bg, QColor fg) {
 	int realSize = size * DevicePixelRatio();
-#ifndef OS_MAC_OLD
 	auto result = QImage(realSize, realSize, QImage::Format::Format_Grayscale8);
-#else // OS_MAC_OLD
-	auto result = QImage(realSize, realSize, QImage::Format::Format_RGB32);
-#endif // OS_MAC_OLD
 	{
 		QPainter p(&result);
 		PainterHighQualityEnabler hq(p);
